JSError class
- Available extensions
- Annotations
-
- @JS()
- @staticInterop
Constructors
- JSError()
Properties
- code → JSString?
-
Available on JSError, provided by the JSErrorExtension extension
no setter - customData → JSAny
-
Available on JSError, provided by the JSErrorExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- message → JSString?
-
Available on JSError, provided by the JSErrorExtension extension
no setter - name → JSString?
-
Available on JSError, provided by the JSErrorExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stack → JSString?
-
Available on JSError, provided by the JSErrorExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited